@@ -913,7 +913,8 @@ func (b *byteReader) Read(p []byte) (int, error) {
 func (b *byteReader) ReadByte() (byte, error) {
 	_, err := b.r.Read(b.b)
 	if len(b.b) > 0 {
-		return b.b[0], nil
+		// issue #38
+		return b.b[0], err
 	}
 	var c byte
 	return c, err
@@ -1036,8 +1037,13 @@ func marshalMapToXmlIndent(doIndent bool, b *bytes.Buffer, key string, value int
 
 	// start the XML tag with required indentaton and padding
 	if doIndent {
-		if _, err = b.WriteString(p.padding); err != nil {
-			return err
+		switch value.(type) {
+		case []interface{}, []string:
+			// list processing handles indentation for all elements
+		default:
+			if _, err = b.WriteString(p.padding); err != nil {
+				return err
+			}
 		}
 	}
 	switch value.(type) {
